@@ -35,6 +35,10 @@ be provided at some point... watch this space!
 
 TODOs:
 
+  For 2.2.2:
+   * In set_value, if first item is non-int, treat as None-indexed
+   * Refine value string heuristic for strings with ints in them?
+
   For 2.2.0:
    * Add Sphinx docs.
    * Preserve comments from read -> write (needs full-line/inline comment
@@ -47,7 +51,7 @@ TODOs:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch>"
-__version__ = "2.1.0"
+__version__ = "2.1.1"
 
 
 
@@ -82,7 +86,10 @@ def _autostr(var, precision=8):
     """Automatically format numerical types as the right sort of string."""
     if type(var) is float:
         return ("% ." + str(precision) + "e") % var
-    return str(var)
+    elif not hasattr(var, "__iter__"):
+        return str(var)
+    else:
+        return ",".join(_autostr(subval) for subval in var)
 
 def _autotuple(a):
     """Automatically convert the supplied iterable to a scalar or tuple as appropriate."""
@@ -168,6 +175,14 @@ class Block(object):
             raise AccessError("Block entries must be iterable")
         ## Auto-convert the types in the list
         args = map(_autotype, args)
+        ## Re-join consecutive strings into single entries
+        i = 0
+        while i < len(args)-1:
+            if type(args[i]) is str and type(args[i+1]) is str:
+                args[i] += " " + args[i+1]
+                del args[i+1]
+                continue
+            i += 1
         ## Add the entry to the map, with appropriate indices
         self.set_value(*args)
 
@@ -225,6 +240,10 @@ class Block(object):
         """Access the block item keys."""
         return self.entries.keys()
 
+    def values(self):
+        """Access the block item values."""
+        return self.entries.values()
+
     def items(self, key=None):
         """Access the block items as (key,value) tuples.
 
@@ -254,14 +273,7 @@ class Block(object):
         s = self.name
         if self.q is not None:
             s += " (Q=%s)" % self.q
-        def _format_kv(k, v):
-            if type(k) is not tuple:
-                s = "%r" % k
-            else:
-                s = ",".join("%r" % subindex for subindex in k)
-            s += " : %s" % repr(v)
-            return s
-        s += " { " + "; ".join(_format_kv(k, v) for k, v in self.items()) + " }"
+        s += " { " + "; ".join(_autostr(k) + " : " + _autostr(v) for k, v in self.items()) + " }"
         return s
 
 
@@ -288,7 +300,7 @@ class Decay(object):
         return cmp(other.br, self.br)
 
     def __repr__(self):
-        return "%.8e %s" % (self.br, self.ids)
+        return "% .8e %s" % (self.br, self.ids)
 
 
 class Particle(object):
@@ -439,7 +451,7 @@ def writeSLHADecays(decays, ignorenobr=False, precision=8):
         decaystrs = []
         for d in particle.decays:
             if d.br > 0.0 or not ignorenobr:
-                products_str = sep.join(map(str, d.ids))
+                products_str = sep.join("% d" % i for i in d.ids)
                 decaystr = sep + _autostr(d.br, precision) + sep + str(len(d.ids)) + sep + products_str
                 decaystrs.append(decaystr)
         blockstr += "\n".join(decaystrs)
@@ -1101,17 +1113,6 @@ def writeISAWIGFile(isafilename, blocks, decays, **kwargs):
     f.close()
 
 
-def writeISAJETFile(isafilename, blocks, decays, **kwargs):
-    """
-    Write an ISAJET file from the supplied blocks and decays dicts (see writeISAJET).
-
-    Other keyword parameters are passed to writeISAJET.
-    """
-    f = open(isafilename, "w")
-    f.write(writeISAWIG(blocks, decays, kwargs))
-    f.close()
-
-
 
 ###############################################################################
 ## Main function for module testing
